1.0 (2014-08-??)
================

- Updated to use Django 1.6
- Registered project for translation at https://www.transifex.com/projects/p/django-inventory/
- Code cleanups
- Conversion of view to class based views
- Capitalization of string
- Improve project files layout
- Improve coding conventions
- Removal of included 3rd party modules
- Update of required modules and libraries versions
- Removal of obsolete code
- Removal of obsolete scripts and instructions
- License change, Django Inventory in now licensed under the Apache 2.0 License
- PyPI package, Django Inventory in now available on PyPI: https://pypi.python.org/pypi/django-inventory/
